# frozen_string_literal: true

class HousingRequestEntityUpdateJob < ActiveJob::Base
  queue_as :housing_request_entity_update
  unique :until_executed

  def perform(entity_id, siret_was, siren_was)
    e = Hermes::Entity.find(entity_id)

    if siret_was && siren_was
      old_housing_requests = find_housing_requests(siret_was, siren_was) 
      update_housing_requests(old_housing_requests) 
    end 

    new_housing_requests = find_housing_requests(e.siret, e.siren)
    update_housing_requests(new_housing_requests)
  end

  def update_housing_requests(housing_requests)
    housing_requests.batch_size(5).no_timeout.each do |hr|
      begin
        hr.update_entity_relationship(false)
        hr.save!
      rescue Exception => e
        Hermes::LogJob.add_to_queue(
          user_id: nil, 
          code: "HousingRequestEntityUpdateJobError", 
          action: "housing_request : #{hr.id} error : #{e}",
          level: 'error',
        )
      end
    end 
  end 

  def find_housing_requests(siret, siren)
    applicant_ids = Hermes::Applicant.where(
      "$or": [
        {main_employer_siret: siret},
        {main_employer_siret: /^#{siren}/},
      ]
    ).pluck(:id)

    Hermes::HousingRequest.where(
      last_entity_code: nil,
      "$or": [
        {:applicant_used_for_siret.in => applicant_ids},
        {:main_applicant_id.in => applicant_ids, applicant_used_for_siret: nil},
      ]
    )
  end 
end
