# frozen_string_literal: true

module Hermes
  class XmlSopraError
    include Hermes::Concerns::CommonFieldsConcern
    field :item_id, type: BSON::ObjectId
    field :item_class, type: String
    field :path , type: String
    field :playload, type: String
    field :error_content, type: String
    field :code, type: String


    index({ created_at: -1 }, { background: true})

    common_indexes *%i[
      item_id
      item_class
      path
      code
    ]

    def pretty_print(string)
      return nil unless string

      doc = Nokogiri::XML(string,&:noblanks)
      doc.to_xhtml(indent: 2)
    end

    def clean_error_content
      separator = ' ----> '
      return error_content unless error_content.include?(separator)

      error_content.split(separator)[1]
    end 

    def clean_error_xml
      pretty_print(clean_error_content)
    end 

    def extracted_error
      begin 
        h = Hash.from_xml(clean_error_xml)
        return error_content unless h.is_a?(Hash)

        while !(h['erreurs'] || h['errors'])
          return 'Cannot extract this error' if !h || !h.is_a?(Hash)
          h = h[h.keys.first]
        end 

        return h['erreurs']['erreur']['message'] if h['erreurs']
        return h['errors']['error']['message']['content'] if h['errors']

        'Unable to find error'
      rescue Exception => e
        "Error while extracting : #{e}" 
      end 
    end 

  end
end
