require 'rails_helper'
require 'json'
require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')

describe Hermes::Api::Dmo::PublicFormsController, type: :api do
  
  routes { Hermes::Engine.routes }
  include Devise::Test::ControllerHelpers

  let!(:user) {create(:user, first_name: 'Martin', last_name: 'Durand', email: 'martin.durand@gmail.com', roles: ['Administrator'])}


  describe 'GET /captcha' do
    describe 'Getting captcha' do
      before :each do
        authenticated_header(request, user)

        get('captcha')
      end
      it 'returns status code 200' do
          resp = JSON.parse(response.body)
        expect(resp['code']).to eq(200)
      end
    end
  end

  describe 'POST /confirm' do
      before :each do
          authenticated_header(request, user)
          get('captcha')
          resp = JSON.parse(response.body)
          str = resp['message']['captcha']

          arr = str.split(' ')
          if arr[1] == "+"
            res = arr[0].to_i + arr[2].to_i
          else 
            res = arr[0].to_i - arr[2].to_i
          end 
          form = Hermes::Form.create(recipient: "test@gmail.com")

          params = {
              res: res,
              form_id: form.id,
              email: "test@gmail.com",
              content: "test test", 
              form_mailer_token: resp['message']['form_mailer_token']} 
          post('confirm', params)
      end

      it 'returns status code 200' do
          resp =  JSON.parse(response.body)
          expect(resp['code']).to eq(200)
      end
  end
end 

require_relative '../../swagger_helper'

describe Hermes::Api::Dmo::PublicFormsController, type: :request, swagger_doc: 'api/swagger/hermes/swagger_hermes.json' do
  tags = 'API_DMO_PUBLIC_FORMS'
  
  extend HermesSwaggerJsonParams
  include SwaggerJsonAttributes
  let!(:user) {create(:user, first_name: 'Martin', last_name: 'Durand', email: 'martin.durand@gmail.com', roles: ['Administrator'])}



  path '/api/dmo/public_forms/confirm' do
    post 'sending mail' do

      tags tags

      produces 'application/json'
      consumes 'application/json'
      security [Bearer: {}]

      json_params = {}
      json_params[:res] = {type: :string}
      json_params[:form_id] = {type: :string}
      json_params[:email] = {type: :string}
      json_params[:content] = {type: :string}
      json_params[:form_mailer_token] = {type: :string}

      parameter name: :params, in: :body, schema: json_params
    end
  end

  path '/api/dmo/public_forms/captcha' do
    get 'Get captcha' do

      tags tags

      produces 'application/json'
      consumes 'application/json'
      security [Bearer: {}]

      response '200', 'housing_request modified' do
        let(:Authorization) {"Bearer #{token_for(user)}"}

        include_context 'with integration test' # run le test
        include_context 'not containings errors'        
        after do |_example|
          json = JSON.parse(response.body) 
          expect(json['code']).to eq(200)
        end
      end
    end
  end

end
