require 'rails_helper'
require 'vcr_config'
require [Hermes::Engine.root, %w[lib hermes rex_client]].flatten.join('/').to_s

RSpec.describe Hermes::RexClient, type: :helper do

  it 'get user token' do
    VCR.use_cassette("rex_get_token", :match_requests_on => [:method, :uri, :path]) do
      expect(Hermes::RexClient::Client.new.get_token).not_to be_empty
    end
  end

  it 'find entity by id ' do
    VCR.use_cassette("rex_find_entity_by_id", :match_requests_on => [:method, :uri, :path]) do
      expect(Hermes::RexClient::Client.new.find_entity_by_id('795e0ad7-18ca-41b1-b804-4c4e9e00d673')).not_to be_empty
    end
  end

  it 'find lessor by id ' do
    VCR.use_cassette("rex_find_lessor_by_id", :match_requests_on => [:method, :uri, :path]) do
      expect(Hermes::RexClient::Client.new.find_lessor_by_id('a397c0d2-5695-43ef-abff-7d2eb9d2b62b')).not_to be_empty
    end
  end

  it 'find structure by id' do
    VCR.use_cassette("rex_find_structure_by_id", :match_requests_on => [:method, :uri, :path]) do
      expect(Hermes::RexClient::Client.new.find_structure_by_id('a397c0d2-5695-43ef-abff-7d2eb9d2b62b')).not_to be_empty
    end
  end

  it 'search entity on siret name ' do
    VCR.use_cassette("rex_search_entities", :match_requests_on => [:method, :uri, :path]) do
      expect(Hermes::RexClient::Client.new.search_entities({'fields.siret' => '39893387900015'}).length).to eq 1
    end
  end

  it 'search lessor on siret ' do
    VCR.use_cassette("rex_search_lessors", :match_requests_on => [:method, :uri, :path]) do
      expect(Hermes::RexClient::Client.new.search_lessors({'fields.siret' => '52844116500016'}).length).to eq 1
    end
  end

  it 'search structure on id_cristal ' do
    VCR.use_cassette("rex_search_structures", :match_requests_on => [:method, :uri, :path]) do
      expect(Hermes::RexClient::Client.new.search_structures({'fields.id_cristal' => '|52313'}).length).to eq 1
    end
  end

end
